@@ -22,23 +22,22 @@ class TestBanner(NereidTestCase):
     def setUp(self):
         trytond.tests.test_tryton.install_module('nereid_cms')
 
-        self.currency_obj = POOL.get('currency.currency')
-        self.site_obj = POOL.get('nereid.website')
-        self.banner_categ_obj = POOL.get('nereid.cms.banner.category')
-        self.banner_obj = POOL.get('nereid.cms.banner')
-        self.folder_obj = POOL.get('nereid.static.folder')
-        self.file_obj = POOL.get('nereid.static.file')
-        self.company_obj = POOL.get('company.company')
-        self.nereid_user_obj = POOL.get('nereid.user')
-        self.url_map_obj = POOL.get('nereid.url_map')
-        self.language_obj = POOL.get('ir.lang')
-        self.nereid_website_obj = POOL.get('nereid.website')
+        self.Currency = POOL.get('currency.currency')
+        self.Site = POOL.get('nereid.website')
+        self.BannerCategory = POOL.get('nereid.cms.banner.category')
+        self.Banner = POOL.get('nereid.cms.banner')
+        self.Folder = POOL.get('nereid.static.folder')
+        self.File = POOL.get('nereid.static.file')
+        self.Company = POOL.get('company.company')
+        self.NereidUser = POOL.get('nereid.user')
+        self.UrlMap = POOL.get('nereid.url_map')
+        self.Language = POOL.get('ir.lang')
+        self.NereidWebsite = POOL.get('nereid.website')
 
         self.templates = {
             'localhost/home.jinja':
-                '''
-                {% for banner in get_banner_category("test-banners").banners %}
-                {{ banner.get_html(banner.id)|safe }}
+                '''{% for banner in get_banner_category("test-banners").banners %}
+                {{ banner.get_html()|safe }}
                 {% endfor %}
                 ''',
         }
@@ -53,37 +52,37 @@ class TestBanner(NereidTestCase):
         """
         Setup the defaults
         """
-        usd = self.currency_obj.create({
+        usd = self.Currency.create({
             'name': 'US Dollar',
             'code': 'USD',
             'symbol': '$',
         })
-        company_id = self.company_obj.create({
+        company = self.Company.create({
             'name': 'Openlabs',
             'currency': usd
         })
-        guest_user = self.nereid_user_obj.create({
+        guest_user = self.NereidUser.create({
             'name': 'Guest User',
             'display_name': 'Guest User',
             'email': 'guest@openlabs.co.in',
             'password': 'password',
-            'company': company_id,
+            'company': company,
         })
-        self.registered_user_id = self.nereid_user_obj.create({
+        self.registered_user_id = self.NereidUser.create({
             'name': 'Registered User',
             'display_name': 'Registered User',
             'email': 'email@example.com',
             'password': 'password',
-            'company': company_id,
+            'company': company,
         })
 
         # Create website
-        url_map_id, = self.url_map_obj.search([], limit=1)
-        en_us, = self.language_obj.search([('code', '=', 'en_US')])
-        return self.nereid_website_obj.create({
+        url_map, = self.UrlMap.search([], limit=1)
+        en_us, = self.Language.search([('code', '=', 'en_US')])
+        return self.NereidWebsite.create({
             'name': 'localhost',
-            'url_map': url_map_id,
-            'company': company_id,
+            'url_map': url_map,
+            'company': company,
             'application_user': USER,
             'default_language': en_us,
             'guest_user': guest_user,
@@ -102,35 +101,35 @@ class TestBanner(NereidTestCase):
         """
         with Transaction().start(DB_NAME, USER, CONTEXT):
 
-            banner_categ1 = self.banner_categ_obj.create({
+            banner_categ1 = self.BannerCategory.create({
                 'name': 'CAT-A'
             })
-            banner_categ2 = self.banner_categ_obj.create({
+            banner_categ2 = self.BannerCategory.create({
                 'name': 'CAT-B'
             })
 
-            self.banner_obj.create({
+            self.Banner.create({
                 'name': 'CAT-A1',
                 'category': banner_categ1,
                 'type': 'custom_code',
                 'custom_code': 'Custom code A1',
                 'state': 'archived'
             })
-            self.banner_obj.create({
+            self.Banner.create({
                 'name': 'CAT-A2',
                 'category': banner_categ1,
                 'type': 'custom_code',
                 'custom_code': 'Custom code A2',
                 'state': 'published'
             })
-            self.banner_obj.create({
+            self.Banner.create({
                 'name': 'CAT-B1',
                 'category': banner_categ2,
                 'type': 'custom_code',
                 'custom_code': 'Custom code B1',
                 'state': 'archived'
             })
-            self.banner_obj.create({
+            self.Banner.create({
                 'name': 'CAT-B2',
                 'category': banner_categ2,
                 'type': 'custom_code',
@@ -138,12 +137,10 @@ class TestBanner(NereidTestCase):
                 'state': 'published'
             })
 
-            categ1 = self.banner_categ_obj.browse(banner_categ1)
-            categ2 = self.banner_categ_obj.browse(banner_categ2)
-            self.assertEqual(len(categ1.banners), 2)
-            self.assertEqual(len(categ2.banners), 2)
-            self.assertEqual(len(categ1.published_banners), 1)
-            self.assertEqual(len(categ2.published_banners), 1)
+            self.assertEqual(len(banner_categ1.banners), 2)
+            self.assertEqual(len(banner_categ1.banners), 2)
+            self.assertEqual(len(banner_categ1.published_banners), 1)
+            self.assertEqual(len(banner_categ1.published_banners), 1)
 
     def test_0020_banner_image(self):
         """
@@ -152,23 +149,23 @@ class TestBanner(NereidTestCase):
         with Transaction().start(DB_NAME, USER, CONTEXT):
             site = self.setup_defaults()
 
-            category = self.banner_categ_obj.create({
+            category = self.BannerCategory.create({
                 'name': 'test-banners',
                 'website': site
             })
-            folder_id = self.folder_obj.create({
+            folder = self.Folder.create({
                 'description': 'image',
                 'folder_name': 'image'
             })
-            file_id = self.file_obj.create({
+            file = self.File.create({
                 'name': 'logo',
-                'folder': folder_id,
+                'folder': folder,
             })
-            self.banner_obj.create({
+            banner = self.Banner.create({
                 'name': 'Test Image Banner',
                 'category': category,
                 'type': 'image',
-                'file': file_id,
+                'file': file,
                 'state': 'published'
             })
 
@@ -188,11 +185,11 @@ class TestBanner(NereidTestCase):
         with Transaction().start(DB_NAME, USER, CONTEXT):
             site = self.setup_defaults()
 
-            category = self.banner_categ_obj.create({
+            category = self.BannerCategory.create({
                 'name': 'test-banners',
                 'website': site
             })
-            self.banner_obj.create({
+            banner = self.Banner.create({
                 'name': 'Test Remote Image Banner',
                 'category': category,
                 'type': 'remote_image',
@@ -216,11 +213,11 @@ class TestBanner(NereidTestCase):
         with Transaction().start(DB_NAME, USER, CONTEXT):
             site = self.setup_defaults()
 
-            category = self.banner_categ_obj.create({
+            category = self.BannerCategory.create({
                 'name': 'test-banners',
                 'website': site
             })
-            self.banner_obj.create({
+            banner = self.Banner.create({
                 'name': 'Test Remote Image Banner',
                 'category': category,
                 'type': 'custom_code',
@@ -243,23 +240,21 @@ class TestGetHtml(NereidTestCase):
     def setUp(self):
         trytond.tests.test_tryton.install_module('nereid_cms')
 
-        self.currency_obj = POOL.get('currency.currency')
-        self.banner_obj = POOL.get('nereid.cms.banner')
-        self.banner_categ_obj = POOL.get('nereid.cms.banner.category')
-        self.file_obj = POOL.get('nereid.static.file')
-        self.folder_obj = POOL.get('nereid.static.folder')
-        self.folder_obj = POOL.get('nereid.static.folder')
-        self.file_obj = POOL.get('nereid.static.file')
-        self.company_obj = POOL.get('company.company')
-        self.nereid_user_obj = POOL.get('nereid.user')
-        self.url_map_obj = POOL.get('nereid.url_map')
-        self.language_obj = POOL.get('ir.lang')
-        self.nereid_website_obj = POOL.get('nereid.website')
+        self.Currency = POOL.get('currency.currency')
+        self.Banner = POOL.get('nereid.cms.banner')
+        self.BannerCategory = POOL.get('nereid.cms.banner.category')
+        self.File = POOL.get('nereid.static.file')
+        self.Folder = POOL.get('nereid.static.folder')
+        self.Company = POOL.get('company.company')
+        self.NereidUser = POOL.get('nereid.user')
+        self.UrlMap = POOL.get('nereid.url_map')
+        self.Language = POOL.get('ir.lang')
+        self.NereidWebsite = POOL.get('nereid.website')
 
         self.templates = {
             'localhost/home.jinja':
                 '''{% for b in get_banner_category('Category A').banners -%}
-                {{ b.get_html(b.id)|safe }}
+                {{ b.get_html()|safe }}
                 {%- endfor %}
                 ''',
             'localhost/article-category.jinja': '{{ articles|length }}',
@@ -276,37 +271,37 @@ class TestGetHtml(NereidTestCase):
         """
         Setup the defaults
         """
-        usd = self.currency_obj.create({
+        usd = self.Currency.create({
             'name': 'US Dollar',
             'code': 'USD',
             'symbol': '$',
         })
-        company_id = self.company_obj.create({
+        company = self.Company.create({
             'name': 'Openlabs',
             'currency': usd
         })
-        guest_user = self.nereid_user_obj.create({
+        guest_user = self.NereidUser.create({
             'name': 'Guest User',
             'display_name': 'Guest User',
             'email': 'guest@openlabs.co.in',
             'password': 'password',
-            'company': company_id,
+            'company': company,
         })
-        self.registered_user_id = self.nereid_user_obj.create({
+        self.registered_user_id = self.NereidUser.create({
             'name': 'Registered User',
             'display_name': 'Registered User',
             'email': 'email@example.com',
             'password': 'password',
-            'company': company_id,
+            'company': company,
         })
 
         # Create website
-        url_map_id, = self.url_map_obj.search([], limit=1)
-        en_us, = self.language_obj.search([('code', '=', 'en_US')])
-        return self.nereid_website_obj.create({
+        url_map, = self.UrlMap.search([], limit=1)
+        en_us, = self.Language.search([('code', '=', 'en_US')])
+        return self.NereidWebsite.create({
             'name': 'localhost',
-            'url_map': url_map_id,
-            'company': company_id,
+            'url_map': url_map,
+            'company': company,
             'application_user': USER,
             'default_language': en_us,
             'guest_user': guest_user,
@@ -320,22 +315,22 @@ class TestGetHtml(NereidTestCase):
         with Transaction().start(DB_NAME, USER, CONTEXT):
             site = self.setup_defaults()
 
-            banner_categ = self.banner_categ_obj.create({
+            banner_category = self.BannerCategory.create({
                 'name': 'Category A',
                 'website': site,
             })
 
-            image = self.folder_obj.create({
+            image = self.Folder.create({
                 'description': 'image',
                 'folder_name': 'image'
             })
-            file = self.file_obj.create({
+            file = self.File.create({
                 'name': 'logo',
                 'folder': image,
             })
-            self.banner_obj.create({
+            banner = self.Banner.create({
                 'name': 'Test Banner1',
-                'category': banner_categ,
+                'category': banner_category,
                 'type': 'image',
                 'file': file,
                 'state': 'published'
@@ -354,47 +349,42 @@ class TestGetHtml(NereidTestCase):
         Get Html for banners with type `remote_image`.
         """
         with Transaction().start(DB_NAME, USER, CONTEXT):
-            self.setup_defaults()
+            site = self.setup_defaults()
 
-            banner_categ = self.banner_categ_obj.create({
+            banner_category = self.BannerCategory.create({
                 'name': 'Category B'
             })
 
-            banner_id = self.banner_obj.create({
+            banner = self.Banner.create({
                 'name': 'Test Banner2',
-                'category': banner_categ,
+                'category': banner_category,
                 'type': 'remote_image',
-                'remote_image_url': 'http://profile.ak.fbcdn.net/hprofile' +
-                    '-ak-snc4/187819_122589627793765_7532740_n.jpg',
+                'remote_image_url': 'http://profile.ak.fbcdn.net/hprofile-ak-snc4/187819_122589627793765_7532740_n.jpg',
                 'state': 'published'
             })
-            banner = self.banner_obj.browse(banner_id)
-            rv = self.banner_obj.get_html(banner_id)
+            rv = banner.get_html()
             html = objectify.fromstring(rv)
-            self.assertEqual(
-                html.find('img').get('src'), banner.remote_image_url
-            )
+            self.assertEqual(html.find('img').get('src'), banner.remote_image_url)
 
     def test_0030_get_html(self):
         """
         Get Html for banners with type `custom_code`.
         """
         with Transaction().start(DB_NAME, USER, CONTEXT):
-            self.setup_defaults()
+            site = self.setup_defaults()
 
-            banner_categ = self.banner_categ_obj.create({
+            banner_category = self.BannerCategory.create({
                 'name': 'Category C'
             })
 
-            banner_id = self.banner_obj.create({
+            banner = self.Banner.create({
                 'name': 'Test Banner3',
-                'category': banner_categ,
+                'category': banner_category,
                 'type': 'custom_code',
                 'custom_code': 'Custom code for Test Banner3',
                 'state': 'published'
             })
-            banner = self.banner_obj.browse(banner_id)
-            rv = self.banner_obj.get_html(banner_id)
+            rv = banner.get_html()
             self.assertEqual(rv, banner.custom_code)
 
 
