@@ -23,10 +23,6 @@ class TestMenuFor(NereidTestCase):
         """
         Return templates
         """
-        self.templates = {
-            'localhost/home.jinja':
-                '{{ menu_for("identifier", "Category1")|safe }}',
-        }
         return self.templates.get(name)
 
     def setup_defaults(self):
@@ -60,7 +56,7 @@ class TestMenuFor(NereidTestCase):
         # Create website
         url_map_id, = self.url_map_obj.search([], limit=1)
         en_us, = self.language_obj.search([('code', '=', 'en_US')])
-        self.site = self.nereid_website_obj.create({
+        self.site1 = self.nereid_website_obj.create({
             'name': 'localhost',
             'url_map': url_map_id,
             'company': company_id,
@@ -71,8 +67,8 @@ class TestMenuFor(NereidTestCase):
         })
 
     def setUp(self):
-        trytond.tests.test_tryton.install_module('product')
         trytond.tests.test_tryton.install_module('nereid_cms')
+        trytond.tests.test_tryton.install_module('product')
 
         self.currency_obj = POOL.get('currency.currency')
         self.company_obj = POOL.get('company.company')
@@ -80,44 +76,56 @@ class TestMenuFor(NereidTestCase):
         self.url_map_obj = POOL.get('nereid.url_map')
         self.language_obj = POOL.get('ir.lang')
         self.nereid_website_obj = POOL.get('nereid.website')
+
         self.menu_obj = POOL.get('nereid.cms.menu')
 
+        self.templates = {
+            'localhost/home.jinja':
+                '{{ menu_for("identifier", "category-name")|safe }}',
+        }
+
     def test_0010_menu_for(self):
         """Two different website, having same unique identifier in
         nereid.cms.menu
         """
-        menu_obj = POOL.get('nereid.cms.menu')
-        model_obj = POOL.get('ir.model')
-        model_field_obj = POOL.get('ir.model.field')
-        prod_categ_obj = POOL.get('product.category')
-
         with Transaction().start(DB_NAME, USER, CONTEXT):
-
             self.setup_defaults()
+            app = self.get_app()
 
-            prod_categ_obj.create({'name': 'Category1'})
-            model = model_obj.search([
+            ProductCategory = POOL.get('product.category')
+            Model = POOL.get('ir.model')
+            ModelField = POOL.get('ir.model.field')
+
+            product_category = ProductCategory.create({
+                'name': 'Category1'
+            })
+            model = Model.search([
                 ('model', '=', 'product.category')
             ])
-            fields = model_field_obj.search([
+            fields = ModelField.search([
                 ('ttype', '=', 'char'),
                 ('model', '=', model[0])
             ])
-            children_field = model_field_obj.search([
+            children_field = ModelField.search([
                 ('ttype', '=', 'one2many'),
                 ('model', '=', model[0])
             ])
-            menu_obj.create({
+            menu_id1 = self.menu_obj.create({
                 'name': 'menu1',
                 'unique_identifier': 'identifier',
-                'website': self.site,
-                'model': model[0],
-                'children_field': children_field[0],
-                'uri_field': fields[0],
-                'title_field': fields[0],
-                'identifier_field': fields[0]
+                'website': self.site1.id,
+                'model': model[0].id,
+                'children_field': children_field[0].id,
+                'uri_field': fields[0].id,
+                'title_field': fields[0].id,
+                'identifier_field': fields[0].id
             })
-            app = self.get_app()
+
+            self.templates = {
+                'localhost/home.jinja':
+                    '{{ menu_for("identifier", "Category1")|safe }}',
+            }
+
             with app.test_client() as c:
                 response = c.get('/en_US/')
                 rv = literal_eval(response.data)
@@ -128,7 +136,7 @@ def suite():
     suite = unittest.TestSuite()
     suite.addTests(
         unittest.TestLoader().loadTestsFromTestCase(TestMenuFor)
-    )
+        )
     return suite
 
 
